==> e107-0.7.20.tbz: www/e107/e107_languages/English/lan_fpw.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $Source: /cvs_backup/e107_0.7/e107_languages/English/lan_fpw.php,v $
|     $Revision: 11346 $
|     $Date: 2010-02-17 13:56:14 -0500 (Wed, 17 Feb 2010) $
|     $Author: secretr $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Password Reset");

define("LAN_02", "Sorry, unable to send email - please contact the main site administrator.");
define("LAN_03", "Password Reset");
define("LAN_05", "To reset your password please enter the following information");
define("LAN_06", "Attempted password reset");
define("LAN_07", "Someone with IP address ");
define("LAN_08", "attempted to reset the main admin password.");
define("LAN_09", "Password reset from ");
define("LAN_112", "Email address used when signing up");
define("LAN_156", "Submit");
define("LAN_213", "That username/email address was not found in database.");
define("LAN_214", "Unable to reset password");
define("LAN_216", "To validate your new password please go to the following URL ...");
define("LAN_217", "Your new password is now validated, you may now login using your new password.");
define("LAN_218", "Your username is:");
define("LAN_219", "The password associated with that email address has already been reset and cannot be reset again. Please contact the site administrator for more details.");
define("LAN_FPW1","Username");
define("LAN_FPW2","Enter code");
define("LAN_FPW3","Incorrect code entered");
define("LAN_FPW4","A request has already been sent to reset this password, if you did not receive the email, please contact the site administrator for help.");
define("LAN_FPW5","A request to reset your password for");
define("LAN_FPW6","An email has been sent to you with a link that will allow you to reset your password.");
define("LAN_FPW7","This is not a valid link to reset your password.<br />Please contact the site administrator for more details.");
define("LAN_FPW8","Your password has been changed successfully.");
define("LAN_FPW9","The new password is:");
define("LAN_FPW10","Please");
define("LAN_FPW11","log in now");
define("LAN_FPW12","and immediately change your password, for security purposes.");

define("LAN_FPW13", "please follow the instructions in the email to validate your password.");
define("LAN_FPW14", "has been submitted by someone with the IP of");
define("LAN_FPW15", "This does not mean your password has yet been reset.  You must navigate to the link shown below to complete the reset process.");
define("LAN_FPW16", "If you did not request to have your password reset and you do NOT want it reset, you may simply ignore this email");
define("LAN_FPW17", "The link below will be valid for 48 hours.");

?>

==> e107-1.0.3.tbz: www/e107/e107_languages/English/lan_fpw.php <==
<?php
/*
+ ----------------------------------------------------------------------------+
|     e107 website system - Language File.
|
|     $URL: https://e107.svn.sourceforge.net/svnroot/e107/trunk/e107_0.7/e107_languages/English/lan_fpw.php $
|     $Revision: 11678 $
|     $Id: lan_fpw.php 11678 2010-08-22 00:43:45Z e107coders $
|     $Author: e107coders $
+----------------------------------------------------------------------------+
*/
define("PAGE_NAME", "Password Reset");

define("LAN_02", "Sorry, unable to send email - please contact the main site administrator.");
define("LAN_03", "Password Reset");
define("LAN_05", "To reset your password please enter the following information");
define("LAN_06", "Attempted password reset");
define("LAN_07", "Someone with IP address ");
define("LAN_08", "attempted to reset the main admin password.");
define("LAN_09", "Password reset from ");
define("LAN_112", "Email address used when signing up");
define("LAN_156", "Submit");
define("LAN_213", "That username/email address was not found in database.");
define("LAN_214", "Unable to reset password");
define("LAN_216", "To validate your new password please go to the following URL ...");
define("LAN_217", "Your new password is now validated, you may now login using your new password.");
define("LAN_218", "Your username is:");
define("LAN_219", "The password associated with that email address has already been reset and cannot be reset again. Please contact the site administrator for more details.");
define("LAN_FPW1","Username");
define("LAN_FPW2","Enter code");
define("LAN_FPW3","Incorrect code entered");
define("LAN_FPW4","A request has already been sent to reset this password, if you did not receive the email, please contact the site administrator for help.");
define("LAN_FPW5","A request to reset your password for");
define("LAN_FPW6","An email has been sent to you with a link that will allow you to reset your password.");
define("LAN_FPW7","This is not a valid link to reset your password.<br />Please contact the site administrator for more details.");
define("LAN_FPW8","Your password has been changed successfully.");
define("LAN_FPW9","The new password is:");
define("LAN_FPW10","Please");
define("LAN_FPW11","log in now");
define("LAN_FPW12","and immediately change your password, for security purposes.");

define("LAN_FPW13", "please follow the instructions in the email to validate your password.");
define("LAN_FPW14", "has been submitted by someone with the IP of");
define("LAN_FPW15", "This does not mean your password has yet been reset.  You must navigate to the link shown below to complete the reset process.");
define("LAN_FPW16", "If you did not request to have your password reset and you do NOT want it reset, you may simply ignore this email");
define("LAN_FPW17", "The link below will be valid for 48 hours.");

?>
